@@ -25,9 +25,10 @@ Connection::Connection() :
     host(),
     port(6667),
     nick(),
+    real(),
     pass(),
-    autoConnect(false),
-    secure(false)
+    secure(false),
+    channels()
 {
 }
 
