@@ -32,10 +32,6 @@ class MainTabWidget : public TabWidget
 public:
     MainTabWidget(QWidget* parent = 0);
 
-protected:
-    virtual void tabInserted(int index);
-    virtual void tabRemoved(int index);
-
 private slots:
     void applySettings(const Settings& settings);
     void setSessionTitle(const QString& title);
