@@ -20,6 +20,7 @@
 
 #include "messageview.h"
 #include "menu.h"
+#include "session.h"
 #include "settings.h"
 #include "completer.h"
 #include "application.h"
@@ -34,7 +35,6 @@
 #include <QDebug>
 #include <QTime>
 #include <QMenu>
-#include <ircsession.h>
 #include <ircutil.h>
 
 enum ModelRole
@@ -73,6 +73,7 @@ MessageView::MessageView(Irc::Buffer* buffer, QWidget* parent)
 
     d.editFrame->completer()->setModel(d.model);
     connect(d.editFrame, SIGNAL(send(QString)), this, SLOT(onSend(QString)));
+    connect(d.editFrame, SIGNAL(help(QString)), this, SLOT(showHelp(QString)));
 
     d.findFrame->setTextEdit(d.textBrowser);
     (void) new NickHighlighter(d.textBrowser->document());
@@ -86,6 +87,7 @@ MessageView::MessageView(Irc::Buffer* buffer, QWidget* parent)
 
 MessageView::~MessageView()
 {
+    d.buffer->deleteLater();
 }
 
 Irc::Buffer* MessageView::buffer() const
@@ -124,6 +126,11 @@ void MessageView::setBuffer(Irc::Buffer* buffer)
     }
 }
 
+void MessageView::clear()
+{
+    d.textBrowser->clear();
+}
+
 void MessageView::showHelp(const QString& text)
 {
     if (text.isNull())
@@ -176,8 +183,11 @@ void MessageView::receiveMessage(const QString& format, const QStringList& param
     else if (message.startsWith("*"))
         cls = "action";
 
-    const QString time = QTime::currentTime().toString();
-    message = tr("[%1] %2").arg(time).arg(message);
+    if (d.timeStamp)
+    {
+        const QString time = QTime::currentTime().toString();
+        message = tr("[%1] %2").arg(time).arg(message);
+    }
     message = QString("<span class='%1'>%2</span>").arg(cls).arg(message);
     d.textBrowser->append(message);
 
@@ -258,6 +268,7 @@ void MessageView::onAnchorClicked(const QUrl& link)
 
 void MessageView::applySettings(const Settings& settings)
 {
+    d.timeStamp = settings.timeStamp;
     d.textBrowser->setFont(settings.font);
     d.textBrowser->document()->setMaximumBlockCount(settings.maxBlockCount);
 
@@ -398,8 +409,8 @@ void MessageView::msgMessageReceived(const QString& origin, const QString& messa
 {
     bool matches = message.contains(d.buffer->session()->nick());
     QString target = d.buffer->receiver();
-    bool privmsg = !target.startsWith('#') && !target.startsWith('&');
-    if ((matches || privmsg) && !isVisible())
+    bool privmsg = !Session::isChannel(target);
+    if (matches || privmsg)
         emit alert(this, true);
     else
         emit highlight(this, true);
@@ -645,7 +656,7 @@ QString MessageView::prefixedSender(const QString& sender) const
 
 QString MessageView::senderHtml(const QString& sender) const
 {
-    if (sender.isEmpty() || sender.startsWith("#") || sender.startsWith("&"))
+    if (sender.isEmpty() || Session::isChannel(sender))
         return sender;
 
     QString prefixed = prefixedSender(sender);
