@@ -33,9 +33,6 @@ public:
     QString connectionName() const;
     void setConnectionName(const QString& name);
 
-    bool autoConnect() const;
-    void setAutoConnect(bool enabled);
-
 private:
     Ui::ConnectionWizardPage ui;
 };
