@@ -40,6 +40,9 @@ public:
     int maxBlockCount() const;
     void setMaxBlockCount(int count);
 
+    bool timeStamp() const;
+    void setTimeStamp(bool timeStamp);
+
 private:
     Ui::GeneralWizardPage ui;
 };
